# ideenergy

[![Upload Python Package](https://github.com/ldotlopez/ideenergy/actions/workflows/python-publish.yml/badge.svg)](https://github.com/ldotlopez/ideenergy/actions/workflows/python-publish.yml) 
[![CodeQL](https://github.com/ldotlopez/ideenergy/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/ldotlopez/ideenergy/actions/workflows/codeql-analysis.yml)

Programmatic access to consumer energy consumption from https://www.i-de.es/ (Spanish energy distributor)

**Useful links**

  * [Related Home-Assistant component](https://github.com/ldotlopez/ha-ideenergy)
  * [Documentation about other distributors](https://www.genbeta.com/web/como-saber-consumo-electrico-tiempo-real-casa)
